@@ -1,6 +1,10 @@
 use anyhow::Result;
 
-use crate::{document::*, ExportFormat};
+use crate::{
+    ansi::{export_to_ansi_with_options, AnsiOptions},
+    document::*,
+    ColorDepth, ExportFormat,
+};
 
 pub fn export_document(document: &Document, format: &ExportFormat) -> Result<()> {
     match format {
@@ -8,6 +12,7 @@ pub fn export_document(document: &Document, format: &ExportFormat) -> Result<()>
         ExportFormat::Text => export_to_text(document),
         ExportFormat::Csv => export_to_csv(document),
         ExportFormat::Json => export_to_json(document),
+        ExportFormat::Ansi => export_to_ansi(document),
     }
 }
 
@@ -43,17 +48,26 @@ pub fn export_to_markdown(document: &Document) -> Result<()> {
                 };
                 markdown.push_str(&format!("{prefix} {heading_text}\n\n"));
             }
-            DocumentElement::Paragraph { text, formatting } => {
-                let mut formatted_text = text.clone();
+            DocumentElement::Paragraph { runs } => {
+                let mut paragraph_text = String::new();
 
-                if formatting.bold {
-                    formatted_text = format!("**{formatted_text}**");
-                }
-                if formatting.italic {
-                    formatted_text = format!("*{formatted_text}*");
+                for run in runs {
+                    let mut formatted_text = run.text.clone();
+
+                    if run.formatting.bold {
+                        formatted_text = format!("**{formatted_text}**");
+                    }
+                    if run.formatting.italic {
+                        formatted_text = format!("*{formatted_text}*");
+                    }
+                    if run.formatting.strikethrough {
+                        formatted_text = format!("~~{formatted_text}~~");
+                    }
+
+                    paragraph_text.push_str(&formatted_text);
                 }
 
-                markdown.push_str(&format!("{formatted_text}\n\n"));
+                markdown.push_str(&format!("{paragraph_text}\n\n"));
             }
             DocumentElement::List { items, ordered } => {
                 for (i, item) in items.iter().enumerate() {
@@ -64,16 +78,19 @@ pub fn export_to_markdown(document: &Document) -> Result<()> {
                         "- ".to_string()
                     };
 
-                    let mut item_text = item.text.clone();
-                    if false
-                    /* simplified */
-                    {
-                        item_text = format!("**{item_text}**");
-                    }
-                    if false
-                    /* simplified */
-                    {
-                        item_text = format!("*{item_text}*");
+                    let mut item_text = String::new();
+                    for run in &item.runs {
+                        let mut formatted_text = run.text.clone();
+                        if run.formatting.bold {
+                            formatted_text = format!("**{formatted_text}**");
+                        }
+                        if run.formatting.italic {
+                            formatted_text = format!("*{formatted_text}*");
+                        }
+                        if run.formatting.strikethrough {
+                            formatted_text = format!("~~{formatted_text}~~");
+                        }
+                        item_text.push_str(&formatted_text);
                     }
 
                     markdown.push_str(&format!("{indent}{bullet}{item_text}\n"));
@@ -131,6 +148,9 @@ pub fn export_to_markdown(document: &Document) -> Result<()> {
                 };
                 markdown.push_str(&format!("![{alt}]({url}){dimensions}\n\n"));
             }
+            DocumentElement::Equation { latex, .. } => {
+                markdown.push_str(&format!("$${latex}$$\n\n"));
+            }
             DocumentElement::PageBreak => {
                 markdown.push_str("\n---\n\n");
             }
@@ -166,9 +186,8 @@ pub fn format_as_text(document: &Document) -> String {
                 text.push_str(&underline.repeat(heading_text.len()));
                 text.push_str("\n\n");
             }
-            DocumentElement::Paragraph {
-                text: para_text, ..
-            } => {
+            DocumentElement::Paragraph { runs } => {
+                let para_text: String = runs.iter().map(|run| run.text.as_str()).collect();
                 text.push_str(&format!("{para_text}\n\n"));
             }
             DocumentElement::List { items, ordered } => {
@@ -180,7 +199,8 @@ pub fn format_as_text(document: &Document) -> String {
                     };
 
                     let indent = "  ".repeat(item.level as usize);
-                    text.push_str(&format!("{indent}{bullet}{}\n", item.text));
+                    let item_text: String = item.runs.iter().map(|run| run.text.as_str()).collect();
+                    text.push_str(&format!("{indent}{bullet}{item_text}\n"));
                 }
                 text.push('\n');
             }
@@ -249,6 +269,9 @@ pub fn format_as_text(document: &Document) -> String {
                     text.push_str(&format!("[Image: {description}]\n\n"));
                 }
             }
+            DocumentElement::Equation { latex, .. } => {
+                text.push_str(&format!("Equation: {latex}\n\n"));
+            }
         }
     }
 
@@ -290,24 +313,34 @@ fn export_to_text_with_images(document: &Document) {
                 };
                 println!("{prefix} {heading_text}\n");
             }
-            DocumentElement::Paragraph { text, formatting } => {
-                let mut formatted_text = text.clone();
+            DocumentElement::Paragraph { runs } => {
+                let mut paragraph_text = String::new();
 
-                if formatting.bold {
-                    formatted_text = format!("**{formatted_text}**");
-                }
-                if formatting.italic {
-                    formatted_text = format!("*{formatted_text}*");
-                }
-                if formatting.underline {
-                    formatted_text = format!("_{formatted_text}_");
+                for run in runs {
+                    let mut formatted_text = run.text.clone();
+
+                    if run.formatting.bold {
+                        formatted_text = format!("**{formatted_text}**");
+                    }
+                    if run.formatting.italic {
+                        formatted_text = format!("*{formatted_text}*");
+                    }
+                    if run.formatting.underline {
+                        formatted_text = format!("_{formatted_text}_");
+                    }
+                    if run.formatting.strikethrough {
+                        formatted_text = format!("~~{formatted_text}~~");
+                    }
+
+                    paragraph_text.push_str(&formatted_text);
                 }
 
-                println!("{formatted_text}\n");
+                println!("{paragraph_text}\n");
             }
             DocumentElement::List { items, .. } => {
                 for item in items {
-                    println!("- {}", item.text);
+                    let item_text: String = item.runs.iter().map(|run| run.text.as_str()).collect();
+                    println!("- {item_text}");
                 }
                 println!();
             }
@@ -347,6 +380,9 @@ fn export_to_text_with_images(document: &Document) {
                     println!("[Image: {description}]\n");
                 }
             }
+            DocumentElement::Equation { latex, .. } => {
+                println!("Equation: {latex}\n");
+            }
             DocumentElement::PageBreak => {
                 println!("{}\n", "-".repeat(50));
             }
@@ -415,7 +451,10 @@ pub fn extract_citations(document: &Document) -> Result<Vec<Citation>> {
     // Simple citation extraction - look for common citation patterns
     for (index, element) in document.elements.iter().enumerate() {
         let text = match element {
-            DocumentElement::Heading { text, .. } | DocumentElement::Paragraph { text, .. } => text,
+            DocumentElement::Heading { text, .. } => text,
+            DocumentElement::Paragraph { runs } => {
+                &runs.iter().map(|run| run.text.as_str()).collect::<String>()
+            }
             _ => continue,
         };
 
@@ -456,7 +495,8 @@ pub fn extract_bibliography(document: &Document) -> Result<Vec<Citation>> {
                 // Process following elements as bibliography entries
                 for (bib_index, bib_element) in document.elements[index + 1..].iter().enumerate() {
                     match bib_element {
-                        DocumentElement::Paragraph { text, .. } => {
+                        DocumentElement::Paragraph { runs } => {
+                            let text: String = runs.iter().map(|run| run.text.as_str()).collect();
                             if !text.trim().is_empty() {
                                 bibliography.push(Citation {
                                     text: text.clone(),
@@ -467,8 +507,10 @@ pub fn extract_bibliography(document: &Document) -> Result<Vec<Citation>> {
                         }
                         DocumentElement::List { items, .. } => {
                             for item in items {
+                                let text: String =
+                                    item.runs.iter().map(|run| run.text.as_str()).collect();
                                 bibliography.push(Citation {
-                                    text: item.text.clone(),
+                                    text,
                                     element_index: index + bib_index + 1,
                                     citation_type: CitationType::Bibliography,
                                 });
@@ -571,3 +613,29 @@ fn align_text_cell_content(content: &str, alignment: TextAlignment, width: usize
         }
     }
 }
+
+pub fn export_to_ansi(document: &Document) -> Result<()> {
+    let options = AnsiOptions::default();
+    let ansi_output = export_to_ansi_with_options(document, &options)?;
+    print!("{ansi_output}");
+    Ok(())
+}
+
+pub fn export_to_ansi_with_cli_options(
+    document: &Document,
+    terminal_width: Option<usize>,
+    color_depth: &ColorDepth,
+) -> Result<()> {
+    let options = AnsiOptions {
+        terminal_width: terminal_width.unwrap_or_else(|| {
+            std::env::var("COLUMNS")
+                .ok()
+                .and_then(|s| s.parse().ok())
+                .unwrap_or(80)
+        }),
+        color_depth: color_depth.clone(),
+    };
+    let ansi_output = export_to_ansi_with_options(document, &options)?;
+    print!("{ansi_output}");
+    Ok(())
+}
